@@ -59,14 +59,10 @@ import org.apache.http.nio.protocol.BasicAsyncRequestProducer;
 import org.apache.http.nio.protocol.BasicAsyncResponseConsumer;
 import org.apache.http.nio.protocol.BasicAsyncResponseProducer;
 import org.apache.http.nio.protocol.HttpAsyncExchange;
-import org.apache.http.nio.protocol.HttpAsyncExpectationVerifier;
 import org.apache.http.nio.protocol.HttpAsyncRequestConsumer;
 import org.apache.http.nio.protocol.HttpAsyncRequestHandler;
-import org.apache.http.nio.protocol.HttpAsyncRequestHandlerMapper;
 import org.apache.http.nio.protocol.HttpAsyncRequestProducer;
 import org.apache.http.nio.protocol.HttpAsyncResponseConsumer;
-import org.apache.http.nio.protocol.UriHttpAsyncRequestHandlerMapper;
-import org.apache.http.nio.reactor.IOReactorStatus;
 import org.apache.http.nio.reactor.ListenerEndpoint;
 import org.apache.http.nio.testserver.HttpCoreNIOTestBase;
 import org.apache.http.protocol.HttpContext;
@@ -121,28 +117,18 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
         shutDownServer();
     }
 
-    private HttpHost start(
-            final HttpProcessor clientProtocolProcessor,
-            final HttpProcessor serverProtocolProcessor,
-            final HttpAsyncRequestHandlerMapper requestHandlerResolver,
-            final HttpAsyncExpectationVerifier expectationVerifier) throws Exception {
-        this.server.start(serverProtocolProcessor, requestHandlerResolver, expectationVerifier);
-        this.client.start(clientProtocolProcessor);
+    private HttpHost start() throws Exception {
+        this.server.start();
+        this.client.setHttpProcessor(DEFAULT_HTTP_PROC);
+        this.client.start();
 
         final ListenerEndpoint endpoint = this.server.getListenerEndpoint();
         endpoint.waitFor();
 
-        Assert.assertEquals("Test server status", IOReactorStatus.ACTIVE, this.server.getStatus());
         final InetSocketAddress address = (InetSocketAddress) endpoint.getAddress();
         return new HttpHost("localhost", address.getPort(), getScheme().name());
     }
 
-    private HttpHost start(
-            final HttpAsyncRequestHandlerMapper requestHandlerResolver,
-            final HttpAsyncExpectationVerifier expectationVerifier) throws Exception {
-        return start(DEFAULT_HTTP_PROC, null, requestHandlerResolver, expectationVerifier);
-    }
-
     private static String createRequestUri(final String pattern, final int count) {
         return pattern + "x" + count;
     }
@@ -157,9 +143,8 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
 
     @Test
     public void testHttpGets() throws Exception {
-        final UriHttpAsyncRequestHandlerMapper registry = new UriHttpAsyncRequestHandlerMapper();
-        registry.register("*", new BasicAsyncRequestHandler(new SimpleRequestHandler()));
-        final HttpHost target = start(registry, null);
+        this.server.registerHandler("*", new BasicAsyncRequestHandler(new SimpleRequestHandler()));
+        final HttpHost target = start();
 
         this.client.setMaxPerRoute(3);
         this.client.setMaxTotal(3);
@@ -193,9 +178,8 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
 
     @Test
     public void testHttpHeads() throws Exception {
-        final UriHttpAsyncRequestHandlerMapper registry = new UriHttpAsyncRequestHandlerMapper();
-        registry.register("*", new BasicAsyncRequestHandler(new SimpleRequestHandler()));
-        final HttpHost target = start(registry, null);
+        this.server.registerHandler("*", new BasicAsyncRequestHandler(new SimpleRequestHandler()));
+        final HttpHost target = start();
 
         this.client.setMaxPerRoute(3);
         this.client.setMaxTotal(3);
@@ -226,9 +210,8 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
 
     @Test
     public void testHttpPosts() throws Exception {
-        final UriHttpAsyncRequestHandlerMapper registry = new UriHttpAsyncRequestHandlerMapper();
-        registry.register("*", new BasicAsyncRequestHandler(new SimpleRequestHandler()));
-        final HttpHost target = start(registry, null);
+        this.server.registerHandler("*", new BasicAsyncRequestHandler(new SimpleRequestHandler()));
+        final HttpHost target = start();
 
         this.client.setMaxPerRoute(3);
         this.client.setMaxTotal(3);
@@ -313,9 +296,8 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
 
         }
 
-        final UriHttpAsyncRequestHandlerMapper registry = new UriHttpAsyncRequestHandlerMapper();
-        registry.register("*", new DelayedRequestHandler());
-        final HttpHost target = start(registry, null);
+        this.server.registerHandler("*", new DelayedRequestHandler());
+        final HttpHost target = start();
 
         this.client.setMaxPerRoute(3);
         this.client.setMaxTotal(3);
@@ -363,8 +345,7 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
 
     @Test
     public void testUnexpectedConnectionClosure() throws Exception {
-        final UriHttpAsyncRequestHandlerMapper registry = new UriHttpAsyncRequestHandlerMapper();
-        registry.register("*", new BasicAsyncRequestHandler(new HttpRequestHandler() {
+        this.server.registerHandler("*", new BasicAsyncRequestHandler(new HttpRequestHandler() {
 
             @Override
             public void handle(
@@ -376,7 +357,7 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
             }
 
         }));
-        registry.register("/boom", new BasicAsyncRequestHandler(new HttpRequestHandler() {
+        this.server.registerHandler("/boom", new BasicAsyncRequestHandler(new HttpRequestHandler() {
 
             @Override
             public void handle(
@@ -389,36 +370,28 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
             }
 
         }));
-        final HttpHost target = start(registry, null);
+        final HttpHost target = start();
 
         this.client.setMaxPerRoute(3);
         this.client.setMaxTotal(3);
 
-        for (int i = 0; i < 20; i++) {
+        for (int i = 0; i < 3; i++) {
 
             final HttpAsyncRequestProducer p1 = new BasicAsyncRequestProducer(target, new BasicHttpRequest("GET", "/"));
             final HttpAsyncRequestProducer p2 = new BasicAsyncRequestProducer(target, new BasicHttpRequest("GET", "/"));
             final HttpAsyncRequestProducer p3 = new BasicAsyncRequestProducer(target, new BasicHttpRequest("GET", "/boom"));
-            final HttpAsyncRequestProducer p4 = new BasicAsyncRequestProducer(target, new BasicHttpRequest("GET", "/"));
-            final HttpAsyncRequestProducer p5 = new BasicAsyncRequestProducer(target, new BasicHttpRequest("GET", "/"));
             final List<HttpAsyncRequestProducer> requestProducers = new ArrayList<HttpAsyncRequestProducer>();
             requestProducers.add(p1);
             requestProducers.add(p2);
             requestProducers.add(p3);
-            requestProducers.add(p4);
-            requestProducers.add(p5);
 
             final HttpAsyncResponseConsumer<HttpResponse> c1 = new BasicAsyncResponseConsumer();
             final HttpAsyncResponseConsumer<HttpResponse> c2 = new BasicAsyncResponseConsumer();
             final HttpAsyncResponseConsumer<HttpResponse> c3 = new BasicAsyncResponseConsumer();
-            final HttpAsyncResponseConsumer<HttpResponse> c4 = new BasicAsyncResponseConsumer();
-            final HttpAsyncResponseConsumer<HttpResponse> c5 = new BasicAsyncResponseConsumer();
             final List<HttpAsyncResponseConsumer<HttpResponse>> responseConsumers = new ArrayList<HttpAsyncResponseConsumer<HttpResponse>>();
             responseConsumers.add(c1);
             responseConsumers.add(c2);
             responseConsumers.add(c3);
-            responseConsumers.add(c4);
-            responseConsumers.add(c5);
 
             final Future<List<HttpResponse>> future = this.client.executePipelined(target, requestProducers, responseConsumers, null, null);
             try {
@@ -434,10 +407,6 @@ public class TestHttpAsyncHandlersPipelining extends HttpCoreNIOTestBase {
             Assert.assertNotNull(c2.getResult());
             Assert.assertTrue(c2.isDone());
             Assert.assertNotNull(c3.getResult());
-            Assert.assertTrue(c4.isDone());
-            Assert.assertNull(c4.getResult());
-            Assert.assertTrue(c5.isDone());
-            Assert.assertNull(c5.getResult());
         }
     }
 
